@@ -1,7 +1,7 @@
 from .conf import *
-from .constant import *
+from .params import *
 from .core import *
 from .fifo import *
 from .statemachine import *
-from .threads import *
+from .workers import *
 from .utils import *
\ No newline at end of file
